@@ -482,17 +482,31 @@ class PredefinedAITemplateTest:
                     # kfserving request header
                     headers = {"Host": service_host_name}
                     # kfserving input
-                    request_json = {
-                        "instances": [
-                            {"review": "test1", "id": 1},
-                            {"review": "test2", "id": 2},
-                            {"review": "test3", "id": 3},
-                        ]
+
+                    result = self.pre_check.hyperdata_client.get_do_samples(
+                        self.pre_check.auth, self.inference_do_id, 10
+                    )
+                    result_data = json.loads(result.data["dto"]["tableString"])
+                    response_data = {
+                        "columns": list(result_data[0].keys()),
+                        "rows": [],
                     }
+                    for data_dict in result_data:
+                        response_data["rows"].append(list(map(str, list(data_dict.values()))))
+
+                    request_json = {"instances": []}
+                    for row in response_data["rows"]:
+                        instance = {}
+                        for idx, val in enumerate(row):
+                            instance[response_data["columns"][idx]] = val
+                        request_json["instances"].append(instance)
+                    print("In test, serving uses inference input data as serving input data.")
+                    print("serving_input_data: ", request_json)
                     try_cnt = 0
                     while try_cnt < 10:
                         res = requests.post(url, headers=headers, data=json.dumps(request_json))
                         if res.status_code == 200:
+                            print("serving_output_data: ", res.text)
                             print("serving succeeded.")
                             return
                         sleep(5)
